# SPDX-FileCopyrightText: 2024 Tom Hubrecht <tom.hubrecht@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2

{ lib, pkgs, ... }:

let
  dgn-keys = import ../keys;

  dgn-members = (import ../meta lib).organization.groups.root;
in

{
  imports = [ ./dgn-install ];

  boot = {
    blacklistedKernelModules = [ "snd_pcsp" ];
    kernelPackages = pkgs.linuxPackages_latest;
    tmp.cleanOnBoot = true;

    loader = {
      systemd-boot.enable = true;
      efi.canTouchEfiVariables = true;
    };

    supportedFilesystems = [
      "exfat"
      "zfs"
      "bcachefs"
    ];

    swraid.enable = lib.mkForce false;
  };

  console.keyMap = "fr";

  services = {
    openssh.enable = true;
  };

  users.users.root.openssh.authorizedKeys.keys = dgn-keys.getKeys dgn-members;
}
