# SPDX-FileCopyrightText: 2024 Maurice Debray <maurice.debray@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2

{ config, pkgs, ... }:
let
  host = "podcasts.dgnum.eu";
in
{
  services = {
    castopod = {
      enable = true;
      localDomain = host;
      environmentFile = config.age.secrets.castopod-environment_file.path;
      maxUploadSize = "512M";
      settings = {
        "email.fromEmail" = "noreply@infra.dgnum.eu";
        "email.SMTPHost" = "kurisu.lahfa.xyz";
        "email.SMTPUser" = "web-services@infra.dgnum.eu";
        "email.SMTPPort" = "587";

        "media.fileManager" = "s3";
        "media.baseURL" = "https://castopod-dgnum.cdn.dgnum.eu/";
        "media.s3.endpoint" = "https://s3.dgnum.eu/";
        "media.s3.region" = "garage";
        "media.s3.bucket" = "castopod-dgnum";
        "media.s3.pathStyleEndpoint" = true;

        "restapi.enabled" = true;
        "restapi.basicAuthUsername" = "castopod";
        "restapi.basicAuth" = true;
      };
      database.createLocally = true;
      configureNginx = true;
    };

    mysql.package = pkgs.mariadb;

    nginx.virtualHosts.${host} = {
      forceSSL = true;
      enableACME = true;
    };
  };
}
