# SPDX-FileCopyrightText: 2024 Tom Hubrecht <tom.hubrecht@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2

{
  pkgs,
  sources,
  config,
  ...
}:

let
  nix-pkgs = import sources.nix-pkgs { inherit pkgs; };
in

{
  services.django-apps.sites.wikiens = {
    source = "https://git.dgnum.eu/DGNum/wiki-eleves";
    branch = "main";
    domain = "wiki.eleves.ens.fr";

    nginx = {
      enableACME = true;
      forceSSL = true;
    };

    webHookSecret = config.age.secrets."webhook-wikiens_token".path;

    python = pkgs.python3.override {
      packageOverrides = _: _: {
        inherit (nix-pkgs)
          django-allauth
          django-allauth-ens
          django-wiki
          loadcredential
          ;
      };
    };

    dependencies =
      ps:
      [
        ps.django
        ps.django-allauth-ens
        ps.django-wiki
        ps.loadcredential
        ps.tinycss2
      ]
      ++ ps.django-allauth.optional-dependencies.socialaccount;

    credentials = {
      SECRET_KEY = config.age.secrets."dj_wikiens-secret_key_file".path;
    };

    environment = {
      WIKIENS_ALLOWED_HOSTS = [ "wiki.eleves.ens.fr" ];
    };
  };
}
